<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Models\User;
use App\Models\Student;
use App\Models\Teacher;
use Illuminate\Support\Facades\Storage;


class AuthController extends Controller
{
    // Login method
    public function login(Request $request)
    {
        try {
            // Validate login credentials
            $credentials = $request->validate([
                'email' => 'required|email',
                'password' => 'required|min:6',
            ]);

            // Attempt to log the user in
            if (Auth::attempt($credentials)) {
                $request->session()->regenerate();

                // Get the authenticated user
                $user = Auth::user();

                // Check the user's role and redirect accordingly
                switch ($user->role) {
                    case 'student':
                        return redirect()->route('account.index');

                    case 'teacher':
                        return redirect()->route('teacher.dashboard');

                    case 'admin':
                        return redirect()->route('admin.dashboard');

                    default:
                        Auth::logout();
                        return redirect()->route('login')->withErrors([
                            'role' => 'Unauthorized role. Please contact support.',
                        ]);
                }
            }

            // If authentication fails
            return back()->withErrors([
                'email' => 'The provided credentials do not match our records.',
            ])->onlyInput('email');
        } catch (\Exception $e) {
            return back()->withErrors(['error' => $e->getMessage()]);
        }
    }

    // Register a student
    public function registerStudent(Request $request)
    {
        try {
            // Validate registration data
            $data = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email',
                'password' => 'required|min:6|confirmed',
                'age' => 'required|integer',
                'grade_level' => 'required|string',
                'system' => 'required|in:American,British,Masry',
            ]);

            // Create the user
            $user = User::create([
                'name' => $data['name'],
                'email' => $data['email'],
                'password' => Hash::make($data['password']),
                'role' => 'student',
            ]);

            // Create the student profile
            Student::create([
                'user_id' => $user->id,
                'name' => $data['name'],
                'age' => $data['age'],
                'grade_level' => $data['grade_level'],
                'system' => $data['system'],
            ]);
        if(Auth::user()->role='amdin')
                return redirect()->back()->with('success', 'Student registered successfully.');
        else{
            return redirect()->route('login')->with('success', 'Student registered successfully.');
        }
        } catch (\Exception $e) {
            return back()->withErrors(['error' => $e->getMessage()]);
        }
    }

    public function addTeacher(Request $request)
    {
        try {
            // Validate teacher data
            $data = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email',
                'password' => 'required|min:6',
                'subject' => 'required|string',
                'profile_photo' => 'nullable|string',
                'price_per_session' => 'nullable|numeric|min:0',
            ]);
    
            // Create the user
            $user = User::create([
                'name' => $data['name'],
                'email' => $data['email'],
                'password' => Hash::make($data['password']),
                'role' => 'teacher',
            ]);
    
            // Create the teacher profile
            $teacher = Teacher::create([
                'user_id' => $user->id,
                'name' => $data['name'],
                'subject' => $data['subject'],
                'profile_photo' => $data['profile_photo'],
                'price_per_session' => $data['price_per_session'],
            ]);
    
            return redirect()->back()->with('success', 'Teacher added successfully.');
        } catch (\Illuminate\Validation\ValidationException $e) {
            return back()->withErrors($e->validator->errors())->withInput();
        } catch (\Exception $e) {
            return back()->withErrors(['error' => $e->getMessage()]);
        }
    }

    // Update a student
    public function updateStudent(Request $request, $id)
    {
        $student = Student::findOrFail($id);
        try {
            // Validate update data
            $data = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email,' . $student->user_id, 
                'password' => 'nullable|min:6',
                'age' => 'required|integer',
                'grade_level' => 'required|string',
                'system' => 'required|in:American,British,Masry',
            ]);

            // Find the user and student profile
            $user = User::findOrFail($student->user_id);
            $student = Student::where('user_id', $user->id)->firstOrFail();

            // Update user information
            $user->update([
                'name' => $data['name'],
                'email' => $data['email'],
                'password' => $data['password'] ? Hash::make($data['password']) : $user->password,
            ]);

            // Update student profile
            $student->update([
                'name' => $data['name'],
                'age' => $data['age'],
                'grade_level' => $data['grade_level'],
                'system' => $data['system'],
            ]);

            return redirect()->back()->with('success', 'Student updated successfully.');
        } catch (\Exception $e) {
            return back()->withErrors(['error' => $e->getMessage()]);
        }
    }

    public function updateTeacher(Request $request, $id)
    {
        try {
            $teacher = Teacher::findOrFail($id);
    
            // Validate input
            $data = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email,' . $teacher->user_id, // Allow same email for the current user
                'password' => 'nullable|min:6', // Optional
                'subject' => 'required|string',
                'profile_photo' => 'nullable|string',
                'price_per_session' => 'nullable|numeric|min:0',
                'balance' => 'required|numeric|min:0',

            ]);
    
            // Update related user info
            $teacher->user->update([
                'name' => $data['name'],
                'email' => $data['email'],
                'password' => $data['password'] ? Hash::make($data['password']) : $teacher->user->password, // Update password only if provided
            ]);
    
            // Update teacher-specific info
            $teacher->update([
                'name' => $data['name'],
                'subject' => $data['subject'],
                'profile_photo' => $data['profile_photo'],
                'price_per_session' => $data['price_per_session'],
                'balance' => $data['balance'],

            ]);
    
            return redirect()->back()->with('success', 'Teacher updated successfully.');
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $e) {
            return redirect()->back()->with('error', 'Teacher not found.');
        } catch (\Illuminate\Validation\ValidationException $e) {
            return redirect()->back()
                ->withErrors($e->validator)
                ->withInput();
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'An unexpected error occurred. Please try again later.'."  " .$e);
        }
    }
    


    // Add an admin
    public function addAdmin(Request $request)
    {
        try {
            // Validate admin data
            $data = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email',
                'password' => 'required|min:6',
            ]);

            // Create the user
            User::create([
                'name' => $data['name'],
                'email' => $data['email'],
                'password' => Hash::make($data['password']),
                'role' => 'admin',
            ]);

            return redirect()->back()->with('success', 'Admin added successfully.');
        } catch (\Exception $e) {
            return back()->withErrors(['error' => $e->getMessage()]);
        }
    }
    public function update(Request $request, $id)
    {
        try {
            $user = User::findOrFail($id);

            // Validate the incoming data
            $validatedData = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|max:255|unique:users,email,' . $user->id,
                'age' => 'nullable|integer|min:1',
                'grade_level' => 'nullable|string|max:255',
                'system' => 'nullable|string|max:255',
                'subject' => 'nullable|string|max:255',
                'price_per_session' => 'nullable|numeric',
                'profile_photo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            ]);

            // Update the general user fields
            $user->name = $validatedData['name'];
            $user->email = $validatedData['email'];
            if ($request->hasFile('profile_photo')) {
                // Remove old profile photo if it exists
                if ($user->profile_photo && Storage::disk('public')->exists($user->profile_photo)) {
                    Storage::disk('public')->delete($user->profile_photo);
                }
                // Store the new profile photo
                $path = $request->file('profile_photo')->store('profile_photos', 'public');
                $user->profile_photo = $path;
            }

            // Save user
            $user->save();

            // Update role-specific data for Student
            if ($user->isStudent()) {
                // Check if a student record already exists for the user
                $student = $user->student ?? new Student();
                $student->user_id = $user->id;
                $student->name = $validatedData['name']; // Assign name here if necessary
                $student->age = $validatedData['age'] ?? $student->age;
                $student->grade_level = $validatedData['grade_level'] ?? $student->grade_level;
                $student->system = $validatedData['system'] ?? $student->system;
                $student->save(); // This will either update or insert based on existence
            } 
            // Update role-specific data for Teacher
            elseif ($user->isTeacher()) {
                $teacher = $user->teacher ?? new Teacher();
                $teacher->user_id = $user->id;
                $teacher->name = $validatedData['name']; // Assign name here if necessary
                $teacher->subject = $validatedData['subject'] ?? $teacher->subject;
                $teacher->price_per_session = $validatedData['price_per_session'] ?? $teacher->price_per_session;
                $teacher->save();
            }

            // Redirect to profile page with success message
            return redirect()->back()->with('success', 'Profile updated successfully!');
        } catch (\Exception $e) {
            // Catch any exception and display an error message
            return redirect()->back()->with('error', 'Failed to update profile: ' . $e->getMessage());
        }
    }
    public function deleteTeacher($teacherId)
    {
        try {
            // Find the teacher by ID
            $teacher = Teacher::findOrFail($teacherId);

            // Get the user associated with the teacher
            $user = User::findOrFail($teacher->user_id);

            // Delete the teacher profile
            $teacher->delete();

            // Delete the user (this will also delete the teacher's related user)
            $user->delete();

            return redirect()->back()->with('success', 'Teacher and associated user deleted successfully.');
        } catch (\Exception $e) {
            return back()->withErrors(['error' => 'Error deleting teacher: ' . $e->getMessage()]);
        }
    }

    public function deleteStudents($studentId)
    {
        try {
            // Find the teacher by ID
            $student = Student::findOrFail($studentId);

            // Get the user associated with the teacher
            $user = User::findOrFail($student->user_id);

            // Delete the teacher profile
            $student->delete();

            // Delete the user (this will also delete the teacher's related user)
            $user->delete();

            return redirect()->back()->with('success', 'Teacher and associated user deleted successfully.');
        } catch (\Exception $e) {
            return back()->withErrors(['error' => 'Error deleting teacher: ' . $e->getMessage()]);
        }
    }


    public function logout(Request $request)
    {
        try {
            // Logout the user
            Auth::logout();

            // Invalidate the session
            $request->session()->invalidate();

            // Regenerate CSRF token
            $request->session()->regenerateToken();

            // Redirect to login page
            return redirect()->route('login')->with('success', 'You have been logged out successfully.');
        } catch (\Exception $e) {
            // Handle any exceptions and return an error message
            return back()->withErrors(['logout' => 'Failed to log out. Error: ' . $e->getMessage()]);
        }
    }

}
