<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Lecture;
use App\Models\Course;
use App\Models\User; // Assuming teachers are users
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class LectureController extends Controller
{
    // Show all lectures for a specific course
    public function index($courseId)
    {
        // الحصول على الكورس باستخدام Course ID
        $course = Course::findOrFail($courseId);


        // التحقق مما إذا كان المستخدم الحالي هو المعلم المسجل لهذا الكورس
        $isTeacher = $course->teachers()->where('teacher_id', Auth::user()->teacher->id)->exists();

        if (!$isTeacher) {
            // إذا لم يكن المستخدم هو المعلم، نعيد توجيهه مع رسالة خطأ
            return redirect()->route('teacher.dashboard')->with('error', 'أنت لست معلمًا لهذا الكورس.');
        }

        // إذا كان المعلم هو المستخدم الحالي، نعرض المحاضرات الخاصة بهذا الكورس
        $lectures = $course->lectures()->where('teacher_id', Auth::user()->teacher->id)->get();

        // إرجاع العرض مع المحاضرات والكورس
        return view('teacher.coursePage', compact('lectures', 'course'));
    }


    // Show form for creating a new lecture
    public function create($courseId)
    {
        $course = Course::findOrFail($courseId);
        $teachers = User::all(); // Get all users to choose a teacher
        return view('lectures.create', compact('course', 'teachers'));
    }

// Store a newly created lecture
public function store(Request $request, $courseId)
{
    try {
        $request->validate([
            'title' => 'required|string|max:255',
            'description' => 'nullable|string',
            'start_time' => 'required|date',
            'duration' => 'required|integer',
            'price' => 'required|numeric|min:0',
            'what_learn' => 'nullable|string',
            'lecture_zoom' => 'nullable|string',
            'lecture_img' => 'nullable|image|mimes:jpg,jpeg,png,svg|max:2048',
            'lecture_video' => 'nullable|mimes:mp4,mkv,avi|max:4096000', // Max size of 4GB for video
        ]);

        $course = Course::findOrFail($courseId);

        $lecture = new Lecture();
        $lecture->course_id = $course->id;
        $lecture->teacher_id = Auth::user()->teacher->id;
        $lecture->title = $request->title;
        $lecture->description = $request->description;
        $lecture->start_time = $request->start_time;
        $lecture->duration = $request->duration;
        $lecture->price = $request->price;
        $lecture->what_learn = $request->what_learn;
        $lecture->lecture_zoom = $request->lecture_zoom;

        // Handle lecture image upload
        if ($request->hasFile('lecture_img')) {
            $imagePath = $request->file('lecture_img')->store('lectures', 'public');
            $lecture->lecture_img = $imagePath;
        }

        // Handle lecture video upload
        if ($request->hasFile('lecture_video')) {
            $videoPath = $request->file('lecture_video')->store('lectures_videos', 'public');
            $lecture->lecture_video = $videoPath;
        }

        $lecture->save();

        return redirect()->route('course.dashboard', $course->id)->with('success', 'Lecture created successfully.');
    } catch (\Exception $e) {
        return back()->with('error', 'An error occurred while creating the lecture: ' . $e->getMessage());
    }
}

    
    

    // Show a specific lecture
    public function show($courseId, $id)
    {
        $course = Course::findOrFail($courseId);
        $lecture = $course->lectures()->findOrFail($id);
        return view('lectures.show', compact('lecture', 'course'));
    }

    // Show form for editing a lecture
    public function edit($courseId, $id)
    {
        $course = Course::findOrFail($courseId);
        $lecture = $course->lectures()->findOrFail($id);
        $teachers = User::all(); // Get all users to choose a teacher
        return view('lectures.edit', compact('lecture', 'course', 'teachers'));
    }

    // Update the specified lecture
    public function update(Request $request, $courseId, $id)
    {
        try {
            $request->validate([
                'title' => 'required|string|max:255',
                'description' => 'nullable|string',
                'start_time' => 'required|date',
                'duration' => 'required|integer',
                'price' => 'required|numeric|min:0',
                'what_learn' => 'nullable|string',
                'lecture_zoom' => 'nullable|string',
                'teacher_id' => 'required|exists:teachers,id',
                'lecture_img' => 'nullable|image|mimes:jpg,jpeg,png,svg|max:2048',
                'lecture_video' => 'nullable|mimes:mp4,mkv,avi|max:4096000', // Max size of 4GB for video
            ]);
    
            $course = Course::findOrFail($courseId);
            $lecture = $course->lectures()->findOrFail($id);
    
            // Update lecture data
            $lecture->title = $request->title;
            $lecture->description = $request->description;
            $lecture->start_time = $request->start_time;
            $lecture->duration = $request->duration;
            $lecture->price = $request->price;
            $lecture->what_learn = $request->what_learn;
            $lecture->lecture_zoom = $request->lecture_zoom;
            $lecture->teacher_id = $request->teacher_id;
    
            // Update lecture image if a new one is uploaded
            if ($request->hasFile('lecture_img')) {
                if ($lecture->lecture_img && Storage::disk('public')->exists($lecture->lecture_img)) {
                    Storage::disk('public')->delete($lecture->lecture_img);
                }
    
                $imagePath = $request->file('lecture_img')->store('lectures', 'public');
                $lecture->lecture_img = $imagePath;
            }
    
            // Update lecture video if a new one is uploaded
            if ($request->hasFile('lecture_video')) {
                if ($lecture->lecture_video && Storage::disk('public')->exists($lecture->lecture_video)) {
                    Storage::disk('public')->delete($lecture->lecture_video);
                }
    
                $videoPath = $request->file('lecture_video')->store('lectures', 'public');
                $lecture->lecture_video = $videoPath;
            }
    
            // Save the updated lecture data
            $lecture->save();
    
            return redirect()->route('course.dashboard', $course->id)->with('success', 'Lecture updated successfully.');
        } catch (\Exception $e) {
            return back()->with('error', 'An error occurred while updating the lecture: ' . $e->getMessage());
        }
    }
    
    

    // Delete the specified lecture
    public function destroy($courseId, $id)
    {
        $course = Course::findOrFail($courseId);
        $lecture = $course->lectures()->findOrFail($id);
        $lecture->delete();

        return redirect()->route('lectures.index', $course->id)->with('success', 'Lecture deleted successfully.');
    }
}
